[latex3-commits] [l3svn] r6117 - l3build: More restrictive test for LuaJITTeX

noreply at latex-project.org noreply at latex-project.org
Tue Sep 29 17:54:49 CEST 2015


Author: joseph
Date: 2015-09-29 17:54:49 +0200 (Tue, 29 Sep 2015)
New Revision: 6117

Modified:
   trunk/l3build/l3build.lua
Log:
l3build: More restrictive test for LuaJITTeX


Modified: trunk/l3build/l3build.lua
===================================================================
--- trunk/l3build/l3build.lua	2015-09-29 14:20:27 UTC (rev 6116)
+++ trunk/l3build/l3build.lua	2015-09-29 15:54:49 UTC (rev 6117)
@@ -796,7 +796,7 @@
   local kpse = require("kpse")
   kpse.set_program_name(engine)
   local maxprintline = tonumber(kpse.expand_var("$max_print_line"))
-  if string.match(engine, "^lua?j?i?t?tex$") then
+  if engine == "luatex" or engine == "luajittex" then
     maxprintline = maxprintline + 1 -- Deal with an out-by-one error
   end
   local lastline = ""
@@ -1009,7 +1009,7 @@
   end
   local errorlevel = 0
   for _,i in ipairs(checkengines) do
     -- Allow for luatex == luajitex for .tlg purposes
     local enginename = i
     if i == "luajittex" then
       enginename = "luatex"
@@ -1047,7 +1047,8 @@
     -- LuaTeX-specific .tlg file and the default engine is not LuaTeX
     if enginename == "luatex"
       and tlgfile ~= name ..  ".luatex" .. tlgext
-      and not string.match(stdengine, "^luaj?i?t?tex$") then
+      and stdengine ~= "luatex"
+      and stdengine ~= "luajittex" then
       local luatlgfile = testdir .. "/" .. name .. ".luatex" ..  tlgext
       if os_windows then
         luatlgfile = unix_to_win(luatlgfile)
@@ -1009,7 +1009,7 @@
   local errorlevel = 0
   for _,i in ipairs(checkengines) do
-    -- Allow for luatex == luajitex for .tlg purposes
+    -- Allow for luatex == luajittex for .tlg purposes
     local enginename = i
     if i == "luajittex" then



More information about the latex3-commits mailing list